"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const io_1 = require("./io");
const errors_1 = require("./errors");
class Input extends io_1.IO {
    constructor(key, name, socket, allowMultipleConnections = false) {
        super(key, name, socket, allowMultipleConnections);
        this.control = null;
    }
    addConnection(connection) {
        if (!this.allowMultipleConnections && this.hasConnection()) {
            throw new Error(errors_1.EngineError.MultipleConnectionsDisallowed);
        }
    }
    addControl(control) {
        this.control = control;
        control.parent = this;
    }
    showControl() {
        return !this.hasConnection() && this.control !== null;
    }
    toJSON() {
        return {
            'connections': this.connections.map(({ data, output }) => {
                if (!output.node) {
                    throw new Error(errors_1.EngineError.NodeNotFoundForOutput + output.key);
                }
                return {
                    nodeId: output.node.id,
                    outputKey: output.key,
                    data,
                };
            }),
        };
    }
}
exports.Input = Input;
//# sourceMappingURL=input.js.map